==> mediawiki-1.21.1.tar.gz: mediawiki-1.21.1/extensions/Cite/SpecialCite.alias.php <==
<?php
/**
 * Aliases for Special:Cite
 *
 * @file
 * @ingroup Extensions
 */

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Cite' => array( 'Cite' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Cite' => array( 'استشهاد' ),
);

/** Egyptian Spoken Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Cite' => array( 'استشهاد' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'Cite' => array( 'উদ্ধৃতি' ),
);

/** Bikol Central (Bikol Central) */
$specialPageAliases['bcl'] = array(
	'Cite' => array( 'Sambitón' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'Cite' => array( 'Цитиране' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'Cite' => array( 'Juhut' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'Cite' => array( 'Menegiñ' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'Cite' => array( 'Citiraj' ),
);

/** буряад (буряад) */
$specialPageAliases['bxr'] = array(
	'Cite' => array( 'Сайт' ),
);

/** Catalan (català) */
$specialPageAliases['ca'] = array(
	'Cite' => array( 'Citau', 'Citeu' ),
);

/** Czech (česky) */
$specialPageAliases['cs'] = array(
	'Cite' => array( 'Citovat' ),
);

/** Danish (dansk) */
$specialPageAliases['da'] = array(
	'Cite' => array( 'Citer' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Cite' => array( 'Zitierhilfe', 'Zitieren' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Cite' => array( 'Sita' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'Cite' => array( 'Citěrowańska_pomoc' ),
);

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = array(
	'Cite' => array( 'Παραπομπή' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Cite' => array( 'Citi' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Cite' => array( 'Citar' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Cite' => array( 'Tsiteerimine' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Cite' => array( 'یادکرد' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'Cite' => array( 'Viittaus' ),
);

/** French (français) */
$specialPageAliases['fr'] = array(
	'Cite' => array( 'Citer' ),
);

/** Franco-Provençal (arpetan) */
$specialPageAliases['frp'] = array(
	'Cite' => array( 'Citar' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Cite' => array( 'Cita', 'Citar' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'Cite' => array( 'Zitierhilf' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Cite' => array( 'ציטוט' ),
);

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = array(
	'Cite' => array( 'Citiraj' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'Cite' => array( 'Citowanska_pomoc' ),
);

/** 湘语 (湘语) */
$specialPageAliases['hsn'] = array(
	'Cite' => array( '建脚注' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Cite' => array( 'Site' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Cite' => array( 'Hivatkozás', 'Irodalomjegyzék' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'Cite' => array( 'Citation' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Cite' => array( 'Kutip' ),
);

/** Igbo (Igbo) */
$specialPageAliases['ig'] = array(
	'Cite' => array( 'Dépùtà' ),
);

/** Ido (Ido) */
$specialPageAliases['io'] = array(
	'Cite' => array( 'Citar' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'Cite' => array( 'Cita' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Cite' => array( '引用' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Cite' => array( '인용' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Cite' => array( 'Zitteere' ),
);

/** Cornish (kernowek) */
$specialPageAliases['kw'] = array(
	'Cite' => array( 'Devynna' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'Cite' => array( 'MostrarManaderos' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'Cite' => array( 'Zitéierhellëf' ),
);

/** Literary Chinese (文言) */
$specialPageAliases['lzh'] = array(
	'Cite' => array( '引文' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Cite' => array( 'Навод' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Cite' => array( 'അവലംബം' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'Cite' => array( 'संदर्भद्या' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'Cite' => array( 'Petik' ),
);

/** Maltese (Malti) */
$specialPageAliases['mt'] = array(
	'Cite' => array( 'Iċċita' ),
);

/** Nahuatl (Nāhuatl) */
$specialPageAliases['nah'] = array(
	'Cite' => array( 'Tlahtoa', 'Citar' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'Cite' => array( 'Siteringshjelp' ),
);

/** Low German (Plattdüütsch) */
$specialPageAliases['nds'] = array(
	'Cite' => array( 'Ziteerhelp' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'Cite' => array( 'Siteerhulpe' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'Cite' => array( 'Citeren' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'Cite' => array( 'Siter' ),
);

/** Occitan (occitan) */
$specialPageAliases['oc'] = array(
	'Cite' => array( 'Citar' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'Cite' => array( 'Cytuj' ),
);

/** Pashto (پښتو) */
$specialPageAliases['ps'] = array(
	'Cite' => array( 'درک' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'Cite' => array( 'Citar' ),
);

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = array(
	'Cite' => array( 'Citar' ),
);

/** Romanian (română) */
$specialPageAliases['ro'] = array(
	'Cite' => array( 'Citează' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Cite' => array( 'Цитата' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'Cite' => array( 'उद्धृत' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'Cite' => array( 'Cita' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'Cite' => array( 'Citovať' ),
);

/** Slovenian (slovenščina) */
$specialPageAliases['sl'] = array(
	'Cite' => array( 'Navedi' ),
);

/** Albanian (shqip) */
$specialPageAliases['sq'] = array(
	'Cite' => array( 'Citim' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'Cite' => array( 'Citera' ),
);

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = array(
	'Cite' => array( 'Taja', 'Hakikisha' ),
);

/** Tetum (tetun) */
$specialPageAliases['tet'] = array(
	'Cite' => array( 'Sita' ),
);

/** Thai (ไทย) */
$specialPageAliases['th'] = array(
	'Cite' => array( 'อ้างอิง' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Cite' => array( 'Sipiin' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Cite' => array( 'KaynakGöster' ),
);

/** Urdu (اردو) */
$specialPageAliases['ur'] = array(
	'Cite' => array( 'حوالہ' ),
);

/** vèneto (vèneto) */
$specialPageAliases['vec'] = array(
	'Cite' => array( 'Cita' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Cite' => array( 'Ghi_chú' ),
);

/** Yiddish (ייִדיש) */
$specialPageAliases['yi'] = array(
	'Cite' => array( 'ציטירן' ),
);

/** Cantonese (粵語) */
$specialPageAliases['yue'] = array(
	'Cite' => array( '引用' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Cite' => array( '引用' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Cite' => array( '引用' ),
);

==> mediawiki-1.22.4.tar.gz: mediawiki-1.22.4/extensions/Cite/SpecialCite.alias.php <==
<?php
/**
 * Aliases for Special:Cite
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Cite' => array( 'Cite' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Cite' => array( 'استشهاد' ),
);

/** Egyptian Spoken Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Cite' => array( 'استشهاد' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'Cite' => array( 'উদ্ধৃতি' ),
);

/** Bikol Central (Bikol Central) */
$specialPageAliases['bcl'] = array(
	'Cite' => array( 'Sambitón' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'Cite' => array( 'Цитиране' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'Cite' => array( 'Juhut' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'Cite' => array( 'Menegiñ' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'Cite' => array( 'Citiraj' ),
);

/** буряад (буряад) */
$specialPageAliases['bxr'] = array(
	'Cite' => array( 'Сайт' ),
);

/** Catalan (català) */
$specialPageAliases['ca'] = array(
	'Cite' => array( 'Citau', 'Citeu' ),
);

/** Min Dong Chinese (Mìng-dĕ̤ng-ngṳ̄) */
$specialPageAliases['cdo'] = array(
	'Cite' => array( '註' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'Cite' => array( 'Дош' ),
);

/** Czech (česky) */
$specialPageAliases['cs'] = array(
	'Cite' => array( 'Citovat' ),
);

/** Danish (dansk) */
$specialPageAliases['da'] = array(
	'Cite' => array( 'Citer' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Cite' => array( 'Zitierhilfe', 'Zitieren' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Cite' => array( 'Sita' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'Cite' => array( 'Citěrowańska_pomoc' ),
);

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = array(
	'Cite' => array( 'Παραπομπή' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Cite' => array( 'Citi' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Cite' => array( 'Citar' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Cite' => array( 'Tsiteerimine' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Cite' => array( 'یادکرد' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'Cite' => array( 'Viittaus' ),
);

/** French (français) */
$specialPageAliases['fr'] = array(
	'Cite' => array( 'Citer' ),
);

/** Franco-Provençal (arpetan) */
$specialPageAliases['frp'] = array(
	'Cite' => array( 'Citar' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Cite' => array( 'Cita', 'Citar' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'Cite' => array( 'Zitierhilf' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Cite' => array( 'ציטוט' ),
);

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = array(
	'Cite' => array( 'Citiraj' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'Cite' => array( 'Citowanska_pomoc' ),
);

/** 湘语 (湘语) */
$specialPageAliases['hsn'] = array(
	'Cite' => array( '建脚注' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Cite' => array( 'Site' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Cite' => array( 'Hivatkozás', 'Irodalomjegyzék' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'Cite' => array( 'Citation' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Cite' => array( 'Kutip' ),
);

/** Igbo (Igbo) */
$specialPageAliases['ig'] = array(
	'Cite' => array( 'Dépùtà' ),
);

/** Ido (Ido) */
$specialPageAliases['io'] = array(
	'Cite' => array( 'Citar' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'Cite' => array( 'Cita' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Cite' => array( '引用' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Cite' => array( '인용' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Cite' => array( 'Zitteere' ),
);

/** Cornish (kernowek) */
$specialPageAliases['kw'] = array(
	'Cite' => array( 'Devynna' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'Cite' => array( 'MostrarManaderos' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'Cite' => array( 'Zitéierhellëf' ),
);

/** Literary Chinese (文言) */
$specialPageAliases['lzh'] = array(
	'Cite' => array( '引文' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Cite' => array( 'Навод' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Cite' => array( 'അവലംബം' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'Cite' => array( 'संदर्भद्या' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'Cite' => array( 'Petik' ),
);

/** Maltese (Malti) */
$specialPageAliases['mt'] = array(
	'Cite' => array( 'Iċċita' ),
);

/** Nahuatl (Nāhuatl) */
$specialPageAliases['nah'] = array(
	'Cite' => array( 'Tlahtoa', 'Citar' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'Cite' => array( 'Siteringshjelp' ),
);

/** Low German (Plattdüütsch) */
$specialPageAliases['nds'] = array(
	'Cite' => array( 'Ziteerhelp' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'Cite' => array( 'Siteerhulpe' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'Cite' => array( 'Citeren' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'Cite' => array( 'Siter' ),
);

/** Occitan (occitan) */
$specialPageAliases['oc'] = array(
	'Cite' => array( 'Citar' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'Cite' => array( 'Cytuj' ),
);

/** Pashto (پښتو) */
$specialPageAliases['ps'] = array(
	'Cite' => array( 'درک' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'Cite' => array( 'Citar' ),
);

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = array(
	'Cite' => array( 'Citar' ),
);

/** Romanian (română) */
$specialPageAliases['ro'] = array(
	'Cite' => array( 'Citează' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Cite' => array( 'Цитата' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'Cite' => array( 'उद्धृत' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'Cite' => array( 'Cita' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'Cite' => array( 'Citovať' ),
);

/** Slovenian (slovenščina) */
$specialPageAliases['sl'] = array(
	'Cite' => array( 'Navedi' ),
);

/** Albanian (shqip) */
$specialPageAliases['sq'] = array(
	'Cite' => array( 'Citim' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'Cite' => array( 'Citera' ),
);

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = array(
	'Cite' => array( 'Taja', 'Hakikisha' ),
);

/** Tetum (tetun) */
$specialPageAliases['tet'] = array(
	'Cite' => array( 'Sita' ),
);

/** Thai (ไทย) */
$specialPageAliases['th'] = array(
	'Cite' => array( 'อ้างอิง' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Cite' => array( 'Sipiin' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Cite' => array( 'KaynakGöster' ),
);

/** Urdu (اردو) */
$specialPageAliases['ur'] = array(
	'Cite' => array( 'حوالہ' ),
);

/** vèneto (vèneto) */
$specialPageAliases['vec'] = array(
	'Cite' => array( 'Cita' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Cite' => array( 'Ghi_chú' ),
);

/** Yiddish (ייִדיש) */
$specialPageAliases['yi'] = array(
	'Cite' => array( 'ציטירן' ),
);

/** Cantonese (粵語) */
$specialPageAliases['yue'] = array(
	'Cite' => array( '引用' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Cite' => array( '引用' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Cite' => array( '引用' ),
);
